# Core Concepts

`measured` is a library for measurements and quantities.

[![PyPi](https://img.shields.io/pypi/v/measured)](https://pypi.org/project/measured)
[![Python Versions](https://img.shields.io/pypi/pyversions/measured)](https://pypi.org/project/measured)

::: measured
    options:
        show_root_heading: true
        members: false

::: measured.Dimension
    options:
        show_root_heading: true

::: measured.Unit
    options:
        show_root_heading: true

::: measured.Prefix
    options:
        show_root_heading: true

::: measured.Quantity
    options:
        show_root_heading: true

::: measured.Logarithm
    options:
        show_root_heading: true

::: measured.LogarithmicUnit
    options:
        show_root_heading: true

::: measured.Level
    options:
        show_root_heading: true

::: measured.Measurement
    options:
        show_root_heading: true

::: measured.approximately
    options:
        show_root_heading: true
